@@ -109,15 +109,15 @@ class Airplane(AeroSandboxObject):
                 points_front = np.zeros((fuse.circumferential_panels, 3))
                 points_rear = np.zeros((fuse.circumferential_panels, 3))
                 for point_index in range(fuse.circumferential_panels):
-                    rot = rotation_matrix_angle_axis(
+                    rot = np.rotation_matrix_3D(
                         2 * pi * point_index / fuse.circumferential_panels,
                         [1, 0, 0],
                         _axis_already_normalized=True
                     )
                     points_front[point_index, :] = rot @ np.array([0, 0, r_front])
                     points_rear[point_index, :] = rot @ np.array([0, 0, r_back])
-                points_front = points_front + np.array(fuse.xyz_le).reshape(-1) + np.array(xsec_1.xyz_c).reshape(-1)
-                points_rear = points_rear + np.array(fuse.xyz_le).reshape(-1) + np.array(xsec_2.xyz_c).reshape(-1)
+                points_front = points_front + np.array(fuse.xyz_le).reshape(-1) + np.array(front_xsec.xyz_c).reshape(-1)
+                points_rear = points_rear + np.array(fuse.xyz_le).reshape(-1) + np.array(back_xsec.xyz_c).reshape(-1)
 
                 for point_index in range(fuse.circumferential_panels):
 
